# coding: utf-8

"""
    Hatchet API

    The Hatchet API

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from datetime import datetime
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing_extensions import Self

from hatchet_sdk.clients.cloud_rest.models.github_app_list_installations200_response_rows_inner_metadata import (
    GithubAppListInstallations200ResponseRowsInnerMetadata,
)


class BuildGet200Response(BaseModel):
    """
    BuildGet200Response
    """  # noqa: E501

    metadata: Optional[GithubAppListInstallations200ResponseRowsInnerMetadata] = None
    status: StrictStr
    status_detail: Optional[StrictStr] = Field(default=None, alias="statusDetail")
    create_time: datetime = Field(alias="createTime")
    start_time: Optional[datetime] = Field(default=None, alias="startTime")
    finish_time: Optional[datetime] = Field(default=None, alias="finishTime")
    build_config_id: StrictStr = Field(alias="buildConfigId")
    __properties: ClassVar[List[str]] = [
        "metadata",
        "status",
        "statusDetail",
        "createTime",
        "startTime",
        "finishTime",
        "buildConfigId",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of BuildGet200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of metadata
        if self.metadata:
            _dict["metadata"] = self.metadata.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of BuildGet200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "metadata": (
                    GithubAppListInstallations200ResponseRowsInnerMetadata.from_dict(
                        obj["metadata"]
                    )
                    if obj.get("metadata") is not None
                    else None
                ),
                "status": obj.get("status"),
                "statusDetail": obj.get("statusDetail"),
                "createTime": obj.get("createTime"),
                "startTime": obj.get("startTime"),
                "finishTime": obj.get("finishTime"),
                "buildConfigId": obj.get("buildConfigId"),
            }
        )
        return _obj
